EXPORTS
	__12TPacketPokerR10RMBufChain @ 1 NONAME R3UNUSED ; TPacketPoker::TPacketPoker(RMBufChain &)
	AddDestinationOptionL__11TPacketHeadPCUcUcUcUc @ 2 NONAME ; TPacketHead::AddDestinationOptionL(unsigned char const *, unsigned char, unsigned char, unsigned char)
	AddDestinationOptionL__11TPacketHeadRC6TPtrC8UcUc @ 3 NONAME ; TPacketHead::AddDestinationOptionL(TPtrC8 const &, unsigned char, unsigned char)
	AddOrdered__18SequenceBlockQueueG10TTcpSeqNumT1 @ 4 NONAME R3UNUSED ; SequenceBlockQueue::AddOrdered(TTcpSeqNum, TTcpSeqNum)
	AddUnordered__18SequenceBlockQueueG10TTcpSeqNumT1 @ 5 NONAME R3UNUSED ; SequenceBlockQueue::AddUnordered(TTcpSeqNum, TTcpSeqNum)
	Add__9TChecksumR10RMBufChainPC12RMBufPktInfoi @ 6 NONAME ; TChecksum::Add(RMBufChain &, RMBufPktInfo const *, int)
	Add__9TChecksumR10RMBufChaini @ 7 NONAME R3UNUSED ; TChecksum::Add(RMBufChain &, int)
	AdjustL__12TPacketPokeri @ 8 NONAME R3UNUSED ; TPacketPoker::AdjustL(int)
	BindToL__20CProtocolInet6BinderP13CProtocolBase @ 9 NONAME R3UNUSED ; CProtocolInet6Binder::BindToL(CProtocolBase *)
	Calculate__9TChecksumPCUsi @ 10 NONAME R3UNUSED ; TChecksum::Calculate(unsigned short const *, int)
	Cancel__14TimeoutFactoryR8RTimeout @ 11 NONAME R3UNUSED ; TimeoutFactory::Cancel(RTimeout &)
	Clear__18SequenceBlockQueue @ 12 NONAME R3UNUSED ; SequenceBlockQueue::Clear(void)
	Clone__12RFlowContextRC12RFlowContext @ 13 NONAME R3UNUSED ; RFlowContext::Clone(RFlowContext const &)
	Close__12CFlowContext @ 14 NONAME R3UNUSED ; CFlowContext::Close(void)
	Close__12RFlowContext @ 15 NONAME R3UNUSED ; RFlowContext::Close(void)
	Connect__12RFlowContext @ 16 NONAME R3UNUSED ; RFlowContext::Connect(void)
	Copy__12RFlowContextR12RFlowContext @ 17 NONAME R3UNUSED ; RFlowContext::Copy(RFlowContext &)
	DoBindTo__20CProtocolInet6BinderP13CProtocolBase @ 18 NONAME R3UNUSED ; CProtocolInet6Binder::DoBindTo(CProtocolBase *)
	ExtHdrGetOrAppendL__11TPacketHeadiRiT2 @ 19 NONAME ; TPacketHead::ExtHdrGetOrAppendL(int, int &, int &)
	ExtHdrGetOrPrependL__11TPacketHeadiRiT2 @ 20 NONAME ; TPacketHead::ExtHdrGetOrPrependL(int, int &, int &)
	ExtHdrGet__11TPacketHeadiRiT2 @ 21 NONAME ; TPacketHead::ExtHdrGet(int, int &, int &)
	FindGap__18SequenceBlockQueueR10TTcpSeqNumT1 @ 22 NONAME R3UNUSED ; SequenceBlockQueue::FindGap(TTcpSeqNum &, TTcpSeqNum &)
	Find__18SequenceBlockQueueG10TTcpSeqNum @ 23 NONAME R3UNUSED ; SequenceBlockQueue::Find(TTcpSeqNum)
	GetIpHeader__15RMBufPacketPeek @ 24 NONAME R3UNUSED ; RMBufPacketPeek::GetIpHeader(void)
	Grab__12RFlowContextR12RFlowContext @ 25 NONAME R3UNUSED ; RFlowContext::Grab(RFlowContext &)
	Init__11TTcpOptions @ 26 NONAME R3UNUSED ; TTcpOptions::Init(void)
	Interface__C12RFlowContext @ 27 NONAME R3UNUSED ; RFlowContext::Interface(void) const
	IsActive__14TimeoutFactoryRC8RTimeout @ 28 NONAME R3UNUSED ; TimeoutFactory::IsActive(RTimeout const &)
	IsExtensionHeader__12TPacketPokeri @ 29 NONAME R3UNUSED ; TPacketPoker::IsExtensionHeader(int)
	Length__C11TTcpOptions @ 30 NONAME R3UNUSED ; TTcpOptions::Length(void) const
	Limit__18SequenceBlockQueuei @ 31 NONAME R3UNUSED ; SequenceBlockQueue::Limit(int)
	NewHostResolverL__20CProtocolInet6Binder @ 32 NONAME R3UNUSED ; CProtocolInet6Binder::NewHostResolverL(void)
	NewL__14TimeoutFactoryUiPvi @ 33 NONAME R3UNUSED ; TimeoutFactory::NewL(unsigned int, void *, int)
	NewNetDatabaseL__20CProtocolInet6Binder @ 34 NONAME R3UNUSED ; CProtocolInet6Binder::NewNetDatabaseL(void)
	NewServiceResolverL__20CProtocolInet6Binder @ 35 NONAME R3UNUSED ; CProtocolInet6Binder::NewServiceResolverL(void)
	Open__12RFlowContextP12MFlowManagerRC9TSockAddrT2UiUiUi @ 36 NONAME ; RFlowContext::Open(MFlowManager *, TSockAddr const &, TSockAddr const &, unsigned int, unsigned int, unsigned int)
	Open__12RFlowContextP12MFlowManagerUi @ 37 NONAME R3UNUSED ; RFlowContext::Open(MFlowManager *, unsigned int)
	Open__12RFlowContextR12RFlowContextP12RMBufPktInfo @ 38 NONAME R3UNUSED ; RFlowContext::Open(RFlowContext &, RMBufPktInfo *)
	OutputOptions__11TTcpOptionsPUcUi @ 39 NONAME R3UNUSED ; TTcpOptions::OutputOptions(unsigned char *, unsigned int)
	OverL__12TPacketPokeri @ 40 NONAME R3UNUSED ; TPacketPoker::OverL(int)
	ProcessOptions__11TTcpOptionsPCUcUi @ 41 NONAME R3UNUSED ; TTcpOptions::ProcessOptions(unsigned char const *, unsigned int)
	Prune__18SequenceBlockQueueG10TTcpSeqNum @ 42 NONAME R3UNUSED ; SequenceBlockQueue::Prune(TTcpSeqNum)
	ReOpen__12RFlowContext @ 43 NONAME R3UNUSED ; RFlowContext::ReOpen(void)
	RetrieveOption__C12CFlowContextUiUiR5TDes8 @ 44 NONAME ; CFlowContext::RetrieveOption(unsigned int, unsigned int, TDes8 &) const
	SetIcmpType__12RFlowContextUiUi @ 45 NONAME R3UNUSED ; RFlowContext::SetIcmpType(unsigned int, unsigned int)
	SetLocalAddr__12RFlowContextRC9TSockAddr @ 46 NONAME R3UNUSED ; RFlowContext::SetLocalAddr(TSockAddr const &)
	SetNotify__12RFlowContextP15MProviderNotify @ 47 NONAME R3UNUSED ; RFlowContext::SetNotify(MProviderNotify *)
	SetProtocol__12RFlowContextUi @ 48 NONAME R3UNUSED ; RFlowContext::SetProtocol(unsigned int)
	SetRemoteAddr__12RFlowContextRC9TSockAddr @ 49 NONAME R3UNUSED ; RFlowContext::SetRemoteAddr(TSockAddr const &)
	SetStatus__12CFlowContexti @ 50 NONAME R3UNUSED ; CFlowContext::SetStatus(int)
	Status__12CFlowContext @ 51 NONAME R3UNUSED ; CFlowContext::Status(void)
	Status__12RFlowContext @ 52 NONAME R3UNUSED ; RFlowContext::Status(void)
	StoreOption__12CFlowContextUiUiRC6TDesC8 @ 53 NONAME ; CFlowContext::StoreOption(unsigned int, unsigned int, TDesC8 const &)
	"_._12CFlowContext" @ 54 NONAME R3UNUSED ; CFlowContext::~CFlowContext(void)
	"_._20CProtocolInet6Binder" @ 55 NONAME R3UNUSED ; CProtocolInet6Binder::~CProtocolInet6Binder(void)
	__12CFlowContextPCvP12MFlowManager @ 56 NONAME R3UNUSED ; CFlowContext::CFlowContext(void const *, MFlowManager *)
	__12CFlowContextPCvP12MFlowManagerR12CFlowContext @ 57 NONAME ; CFlowContext::CFlowContext(void const *, MFlowManager *, CFlowContext &)
	Access__15RMBufPacketPeekiUi @ 58 NONAME ; RMBufPacketPeek::Access(int, unsigned int)
	BindL__17CProtocolPosthookP13CProtocolBaseUi @ 59 NONAME R3UNUSED ; CProtocolPosthook::BindL(CProtocolBase *, unsigned int)
	BindToL__17CProtocolPosthookP13CProtocolBase @ 60 NONAME R3UNUSED ; CProtocolPosthook::BindToL(CProtocolBase *)
	DoBindToL__17CProtocolPosthookP13CProtocolBase @ 61 NONAME R3UNUSED ; CProtocolPosthook::DoBindToL(CProtocolBase *)
	Process__17CProtocolPosthookR10RMBufChainP13CProtocolBase @ 62 NONAME R3UNUSED ; CProtocolPosthook::Process(RMBufChain &, CProtocolBase *)
	Send__17CProtocolPosthookR10RMBufChainP13CProtocolBase @ 63 NONAME R3UNUSED ; CProtocolPosthook::Send(RMBufChain &, CProtocolBase *)
	Unbind__17CProtocolPosthookP13CProtocolBaseUi @ 64 NONAME R3UNUSED ; CProtocolPosthook::Unbind(CProtocolBase *, unsigned int)
	"_._17CProtocolPosthook" @ 65 NONAME R3UNUSED ; CProtocolPosthook::~CProtocolPosthook(void)
	CreateEventManager__13MEventServiceUi @ 66 NONAME R3UNUSED ; MEventService::CreateEventManager(unsigned int)
	CreateDstCache__17MDestinationCachei @ 67 NONAME R3UNUSED ; MDestinationCache::CreateDstCache(int)
	Access__16TInet6PacketBaseR10RMBufChainiii @ 68 NONAME R3UNUSED ; TInet6PacketBase::Access(RMBufChain &, int, int, int)
